==> haskell-monadrandom-0.6.2-66-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monadrandom.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 MonadRandom
version:              0.6.2
visibility:           public
id:                   MonadRandom-0.6.2-6IjbbtL7fMHCvkcNSwNTTD
key:                  MonadRandom-0.6.2-6IjbbtL7fMHCvkcNSwNTTD
license:              BSD-3-Clause
maintainer:           Brent Yorgey <byorgey@gmail.com>
author:               Cale Gibbard and others
synopsis:             Random-number generation monad.
description:          Support for computations which consume random values.
category:             Control
abi:                  7b7e755e2f5997402de1e13cad753a1a
exposed:              True
exposed-modules:
    Control.Monad.Random Control.Monad.Random.Class
    Control.Monad.Random.Lazy Control.Monad.Random.Strict
    Control.Monad.Trans.Random Control.Monad.Trans.Random.Lazy
    Control.Monad.Trans.Random.Strict

import-dirs:          /usr/lib/ghc-9.4.8/site-local/MonadRandom-0.6.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/MonadRandom-0.6.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/MonadRandom-0.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monadrandom
hs-libraries:         HSMonadRandom-0.6.2-6IjbbtL7fMHCvkcNSwNTTD
depends:
    base-4.17.2.1 mtl-2.2.2 primitive-0.9.1.0-2emSnHXTWdc3ipPHrSzrL
    random-1.2.1.3-AELLTL3R5f5HMsp0oxLypG transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:   /usr/share/doc/haskell-monadrandom/html/MonadRandom.haddock
haddock-html:         /usr/share/doc/haskell-monadrandom/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monadrandom-0.6.2-67-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monadrandom.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 MonadRandom
version:              0.6.2
visibility:           public
id:                   MonadRandom-0.6.2-DgVmxKzri7VAlFMMEy8ZtF
key:                  MonadRandom-0.6.2-DgVmxKzri7VAlFMMEy8ZtF
license:              BSD-3-Clause
maintainer:           Brent Yorgey <byorgey@gmail.com>
author:               Cale Gibbard and others
synopsis:             Random-number generation monad.
description:          Support for computations which consume random values.
category:             Control
abi:                  3848a99e3ec17b82cafc48a279184b00
exposed:              True
exposed-modules:
    Control.Monad.Random Control.Monad.Random.Class
    Control.Monad.Random.Lazy Control.Monad.Random.Strict
    Control.Monad.Trans.Random Control.Monad.Trans.Random.Lazy
    Control.Monad.Trans.Random.Strict

import-dirs:          /usr/lib/ghc-9.4.8/site-local/MonadRandom-0.6.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/MonadRandom-0.6.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/MonadRandom-0.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monadrandom
hs-libraries:         HSMonadRandom-0.6.2-DgVmxKzri7VAlFMMEy8ZtF
depends:
    base-4.17.2.1 mtl-2.2.2 primitive-0.9.1.0-BPFoIcduUog2ja2MaonOAo
    random-1.2.1.3-BehtSTiFIU58dvHGLgfoiP transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:   /usr/share/doc/haskell-monadrandom/html/MonadRandom.haddock
haddock-html:         /usr/share/doc/haskell-monadrandom/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
